## Pull Request Templates

Please choose a template below and copy its content to this pull request description:

- [BugFix Template](https://github.com/flaxandteal/bonn-py/tree/main/.github/PULL_REQUEST_TEMPLATES/bug_fix.md)
- [Documentation Updated Template](https://github.com/flaxandteal/bonn-py/tree/main/.github/PULL_REQUEST_TEMPLATES/documentation.md)
- [New feature Template](https://github.com/flaxandteal/bonn-py/tree/main/.github/PULL_REQUEST_TEMPLATES/feature.md)

After copying the relevant template, delete this section.
